@@ -24,11 +24,7 @@ from typing import TYPE_CHECKING, Any, ClassVar, cast
 from uuid import UUID
 
 import httpx
-from bs4 import BeautifulSoup
-from datasets import load_dataset
-from pydantic import BaseModel, ConfigDict, Field, field_validator
-from tenacity import retry, stop_after_attempt, wait_exponential_jitter
-
+import httpx_aiohttp
 from aviary.core import (
     Environment,
     EvalAnswerMode,
@@ -40,6 +36,10 @@ from aviary.core import (
     ToolRequestMessage,
     eval_answer,
 )
+from bs4 import BeautifulSoup
+from datasets import load_dataset
+from pydantic import BaseModel, ConfigDict, Field, field_validator
+from tenacity import retry, stop_after_attempt, wait_exponential_jitter
 
 if TYPE_CHECKING:
     from datasets import Dataset
@@ -424,7 +424,7 @@ class HotPotQAEnv(Environment[HotPotQAEnvState]):
             response_text = self.wiki_cache[search_entity]
         except KeyError:
             # follow_redirects=True because wikipedia frequently redirects to the correct page
-            async with httpx.AsyncClient(
+            async with httpx_aiohttp.HttpxAiohttpClient(
                 follow_redirects=True, proxy=self.proxy
             ) as client:
                 response = await fetch_with_retry(
